Stan Math Library: stan/math/mix/mat/functor/partial_derivative.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
partial_derivative.hpp File Reference
`#include <stan/math/fwd/core.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/rev/core.hpp>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T , typename F >
void | stan::math::partial_derivative (const F &f, const Eigen::Matrix< T, Eigen::Dynamic, 1 > &x, int n, T &fx, T &dfx_dxn)
| Return the partial derivative of the specified multiivariate function at the specified argument. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.